@@ -1,13 +1,14 @@
 
 (when (and os-type--linux-p emacs-dialect--gnuemacs-p)
   (setq backup-inhibited t)
-  (setq backup-directory-alist '(("." . "~/.emacs.d")))
+  (setq backup-directory-alist '(("" . "~/.emacs.d")))
   (setq version-control t)
   (setq kept-new-versions 2)
   (setq kept-old-versions 2))
 
 (when (and os-type--mswindows-p emacs-dialect--gnuemacs-p)
   (setq backup-inhibited t)
+  (setq backup-directory-alist '(("" . "~/.emacs.d")))
   ;;(setq version-control t)
   ;;(setq kept-new-versions 2)
   ;;(setq kept-old-versions 2)
