@@ -6,20 +6,22 @@
 ;; Keywords: J.T.W. Java
 ;; Package: dlisp (Davin's version of elisp)
 ;; Note: in files in the dlisp package, the d- prefix stands for _D_avin's customizations
-;; Version: 1.0
+;; Version: 2.0
 
-;; This program is not part of GNU Emacs
+;; This file is part of GNU Java Training Wheels.
+
+;;; Limitation of Warranty
+
+;; GNU package is free software: you can redistribute it and/or
+;; modify it under the terms of the GNU General Public License as
+;; published by the Free Software Foundation, either version 3 of
+;; the License, or (at your option) any later version.
+
+;; GNU package is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+;; General Public License for more details.
 
-;; This program is free software: you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation, either version 3 of the License, or (at
-;; your option) any later version.
-;;
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more detail.
-;;
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs, see the file COPYING.  If not, see:
 ;;
@@ -171,7 +173,7 @@
 (defun warn--list-to-string (list)
   (let ((ptr list) (str ""))
     (while ptr
-      ;;(debug "False coloured eyes")
+      ;;(debug "The Velvet Underground: Look into her false coloured eyes")
       (setq str (concat str (nth 2 (car ptr))))
       (setq ptr (cdr ptr)))
     str))
@@ -697,17 +699,30 @@
 
 (defun warn--splat-quest (str)
   (save-match-data
-    (while (string-match "\\<QUEST\\>" str)
-      (setq str (concat (substring str 0 (match-beginning 0))
-                        "?"
-                        (substring str (match-end 0)))))
-    (while (string-match "\\\\" str)
-      ;;(debug "Radiohead: Lucky")
-      (setq str (concat (substring str 0 (match-beginning 0))
-                        (substring str (match-end 0)))
-            ))
+    (when (not (eq nil str))
+      (while (string-match "\\<QUEST\\>" str)
+        (setq str (concat (substring str 0 (match-beginning 0))
+                          "?"
+                          (substring str (match-end 0)))))
+      (while (string-match "\\\\" str)
+        ;;(debug "Radiohead: Lucky")
+        (setq str (concat (substring str 0 (match-beginning 0))
+                          (substring str (match-end 0)))
+              ))
+      )
     str))
 
+;; (warn--splat-quest (setq str "\"abc\""))
+;; (warn--cull-quotes (setq str "\"abc\""))
+(defun warn--cull-quotes (str)
+  (when (and str (stringp str) (> (length str) 0))
+    (when (= (aref str 0) ?\")
+      (setq str (substring str 1)))
+    (when (= (aref str (1- (length str))) ?\")
+      (setq str (substring str 0 (1- (length str)))))
+    )
+  str)
+
 (defun warn--buffer-to-string ()
   (buffer-substring-no-properties (point-min) (point-max)))
 
@@ -854,14 +869,6 @@ I am a comment on how to use this function"
     (setq *current-buffer* (current-buffer))
     (eval (read (current-buffer)))))
 
-;; (warn--cull-quotes (setq str "\"abc\""))
-(defun warn--cull-quotes (str)
-  (if (= (aref str 0) ?\")
-      (setq str (substring str 1)))
-  (if (= (aref str (1- (length str))) ?\")
-      (setq str (substring str 0 (1- (length str)))))
-  str)
-
 ;;(message "pre doit")
 
 (defun doit ()
@@ -1181,7 +1188,7 @@ I am a comment on how to use this function"
                        (forward-sexp 1)
                        (point)))
             (setq str (buffer-substring-no-properties end0 p2))
-            (checkpoint "str=%s" str)
+            ;;(checkpoint "str=%s" str)
             (setq form (read-str str))
             ;;(checkpoint "form=%s" form)
             ;;(debug "form")
@@ -1193,12 +1200,12 @@ I am a comment on how to use this function"
             (setq this (format "superfor_%d_" *superfor*))
             (when (not (eq (nth 0 form) 'var))
               (warn--log-message "Error 35: Keyword var missing from superfor construct")
-              (when (and (not (eq (nth 0 form) 'char))
-                         (not (eq (nth 0 form) 'short))
-                         (not (eq (nth 0 form) 'int))
-                         (not (eq (nth 0 form) 'long))
-                         (not (eq (nth 0 form) 'float))
-                         (not (eq (nth 0 form) 'double)))
+              (when (and (not (eq (nth 1 form) 'char))
+                         (not (eq (nth 1 form) 'short))
+                         (not (eq (nth 1 form) 'int))
+                         (not (eq (nth 1 form) 'long))
+                         (not (eq (nth 1 form) 'float))
+                         (not (eq (nth 1 form) 'double)))
                 (warn--log-message (concat
                                     "Error 37:#1 argument type to superfor macro must be"
                                     " one of char/short/int/long/float/double"))))
@@ -1214,22 +1221,20 @@ I am a comment on how to use this function"
                                       " one of char/short/int/long/float/double")))
               (progn
                 ;;(debug "Radiohead: Let Down")
-                (setq type (nth 1 form))
-                (setq T (prin1-to-string type))
-                (setq variable (nth 2 form))
-                (setq variable-equals (prin1-to-string (nth 2 form)))
-                (if (string-match "=" variable-equals)
+                (setq type     (nth 1 form))
+                (setq T        (prin1-to-string type))
+                (setq variable (prin1-to-string (nth 2 form)))
+                (if (string-match "=" variable)
                     (progn
-                      (setq pre-red-str--variable (substring variable-equals 0 (match-beginning 0)))
+                      (setq pre-red-str--variable (substring variable 0 (match-beginning 0)))
                       ;;(string-match "=" variable-equals)
-                      (setq pre-red-str--start    (substring variable-equals (match-end 0)))
+                      (setq pre-red-str--start    (substring variable (match-end 0)))
                       ;;(debug "Radiohead: Fitter Happier")
+                      ;;(debug "Jean Jarre: Equinoxe Part III")
                       (setq variable (if (not (string= "" pre-red-str--variable))
-                                         (read-str pre-red-str--variable)))
+                                         (prin1-to-string (read-str pre-red-str--variable))))
                       (setq start (if (not (string= "" pre-red-str--start))
-                                      (read-str pre-red-str--start)))
-                      (setq variable (prin1-to-string variable))
-                      (setq start    (prin1-to-string start))
+                                      (prin1-to-string (read-str pre-red-str--start))))
                       (cond
                        ((eq (nth 3 form) nil)
                         (setq start (concat start "()"))
@@ -1249,6 +1254,10 @@ I am a comment on how to use this function"
                           ;;(debug "The Pretenders: Kid")
                           (if (eq (nth 7 form) 'step)
                               (setq step-size (nth 8 form))))
+                         ((string-match "(" (prin1-to-string (nth 6 form)))
+                          (setq stop (concat stop (prin1-to-string (nth 6 form))))
+                          (if (eq (nth 7 form) 'step)
+                              (setq step-size (nth 8 form))))
                          ((eq (nth 6 form) 'step)
                           (debug "Pretenders: Private Life")
                           (setq step-size (nth 7 form)))
@@ -1256,7 +1265,7 @@ I am a comment on how to use this function"
                           ;;(debug "Queen: It's a Kind of Magic")
                           )
                          ) ;; END COND!
-                        ;;(if strobe (debug "Queen: One Year of Love"))
+                        (if strobe (debug "Queen: One Year of Love"))
                         )
                        ((string-match "(" (prin1-to-string (nth 3 form)))
                         ;;(debug "Public Enemy: Letter to the New York Post")
@@ -1288,7 +1297,6 @@ I am a comment on how to use this function"
                           ;;(debug "Queen: It's a Kind of Magic")
                           )
                          )
-                        )
                        ((eq (nth 3 form) 'to)
                         (setq to 'to)
                         (setq stop (nth 4 form))
@@ -1307,10 +1315,11 @@ I am a comment on how to use this function"
                         )
                        (t
                         (debug "Dire Straits: The Bug")))
-                      )
-                  (assert (or (eq (nth 3 form) '=)))
+                      )) ;; END PROGN!
+                  ;;(debug "Jean Jarre: Oxygene III")
+                  (assert (eq (nth 3 form) '=))
                   ;;(debug "Joaquin Rodrigo)
-                  (setq start (nth 4 form))
+                  (setq start (prin1-to-string (nth 4 form)))
                   (cond
                    ((eq (nth 5 form) 'to)
                     (setq to 'to))
@@ -1318,21 +1327,21 @@ I am a comment on how to use this function"
                     (setq to 'downto))
                    (t
                      (debug "Dire Straits: Planet of New Orleans")))
-                  (setq stop (nth 6 form))
+                  (setq stop (prin1-to-string (nth 6 form)))
                   (if (eq (nth 7 form) 'step)
                       (progn
-                        (setq step-size (nth 8 form))
-                        ;;(assert (numberp (nth 8 form)))
+                        (setq step-size (and (nth 8 form) (prin1-to-string (nth 8 form))))
+                        (assert (numberp (nth 8 form)))
                         )
-                    ;;(setq step-size 1)
                     )
                   ))
-              ;;(debug "Rod Stewart's Maggie May")
+                ;;(debug "Rod Stewart's Maggie May")
               (progn
                 (setq var         variable)
-                (setq start-2     (warn--cull-quotes (warn--splat-quest (prin1-to-string start))))
-                (setq stop-2      (warn--cull-quotes (warn--splat-quest (prin1-to-string stop))))
-                (setq step-size-2 (warn--splat-quest (prin1-to-string step-size))))
+                (setq start-2     (warn--cull-quotes (warn--splat-quest start)))
+                (setq stop-2      (warn--cull-quotes (warn--splat-quest stop)))
+                (setq step-size-2 (warn--splat-quest (and step-size (prin1-to-string step-size))))
+                ) ;; END PROGN!
               ;; -----------------------------------------------------
               ;;(debug "The Pretenders: Precious")
               (setq this_start     (concat this "start"))
@@ -1365,7 +1374,7 @@ I am a comment on how to use this function"
                                 )         ;; END IF!
                               ";\n")      ;; END CONCAT!
                       )                   ;; END INSERT!
-              ;;(debug "Hot Legs")
+              ;;(debug "Rod Stewart: Hot Legs")
               (setq line 0)
               (setq p-prior
                     (save-excursion
@@ -1398,7 +1407,7 @@ I am a comment on how to use this function"
                               " ((" this_step_size " > 0) ? " var " <= "
                               this_stop " : " var " >= " this_stop "); "
                               var " += " this_step_size ")"))
-              ;;(if strobe (debug "Pretenders: The Wait"))
+              (if strobe (debug "Pretenders: The Wait"))
               ;;(debug "Yehudi Menuhin")
               )))))
 
@@ -1961,7 +1970,7 @@ I am a comment on how to use this function"
                                                                     "\\(boolean\\|char\\|float\\|"
                                                                     "double\\|int\\|long\\|short\\|"
                                                                     "[A-Z]\\|[A-Z]+[a-z][a-zA-Z0-9]*\\)"
-                                                                    "\\([][]\\)*[ \t]+"
+                                                                    "\\([][]*\\)[ \t]+"
                                                                     "\\([a-z][A-Za-z0-9]*\\)") nil t)
             (save-excursion
               (setq n3 (buffer-substring-no-properties (match-beginning 3) (match-end 3)))
@@ -2013,7 +2022,7 @@ I am a comment on how to use this function"
         (when (not (warn--inside-comment-or-string))
           (delete-region (match-beginning 0) (match-end 0))
           (insert " static "))))
-    (checkpoint "doit:43")
+    ;;(checkpoint "doit:43")
     (progn
       ;;(font-lock-fontify-buffer)
       (goto-char (point-min))
@@ -2022,7 +2031,7 @@ I am a comment on how to use this function"
           (forward-char -2)
           (when (not (warn--inside-comment-or-string))
             (delete-region (match-beginning 0) (match-end 0))))))
-    (checkpoint "doit:43b")
+    ;;(checkpoint "doit:43b")
     (progn
       (goto-char (point-min))
       (while (warn--re-search-forward--no-strings-no-comments "\\<var[ \t\r\n]+" nil t)
@@ -2030,7 +2039,7 @@ I am a comment on how to use this function"
           (forward-char -2)
           (when (not (warn--inside-comment-or-string))
             (delete-region (match-beginning 0) (match-end 0))))))
-    (checkpoint "doit:44")
+    ;;(checkpoint "doit:44")
     (progn
       ;;(font-lock-fontify-buffer)
       (goto-char (point-min))
@@ -2046,13 +2055,12 @@ I am a comment on how to use this function"
         (when (not (warn--inside-comment-or-string))
           (delete-region (match-beginning 0) (match-end 0))
           (insert "||"))))
-
-    ;;(checkpoint "doit:46")
+    (checkpoint "doit:46")
     (setq was-error nil)
-    ;;(checkpoint "buffer-name=%s" (buffer-name))
+    (checkpoint "buffer-name=%s" (buffer-name))
     (if warn--err-msgs
         (progn
-          ;;(checkpoint "doit:47")
+          (checkpoint "doit:47")
           (setq was-error t)
           (setq warn--err-msgs (sort warn--err-msgs 'warn--pred))
           (setq warn--err-msgs (cons (list "" 0 "** Stage 1: SJS Debugger Stage 1\n")
@@ -2063,7 +2071,7 @@ I am a comment on how to use this function"
           ;;(error "*** Error compiling SJS code (smeg)")
           ))
     (progn
-      ;;(checkpoint "doit:48")
+      (checkpoint "doit:48")
       ;;(checkpoint "doit:50")
       ;;(checkpoint "buffer-name=%s" (buffer-name))
       ;;(checkpoint "doit:51")
