@@ -4,10 +4,11 @@
 
 ;; Maintainer: Davin Pearson <http://davin.50webs.com>
 ;; Keywords: Java Training Wheels installer
+;; Version 1.2:
 
 ;;; Commentary:
 
-;; This program is not part of GNU Emacs
+;; This program is part of GNU Java Training Wheels
 
 ;; This file provides a mechanism for installing and uninstalling
 ;; J.T.W. code compilation code.  In the code that follows, the d-
@@ -15,13 +16,13 @@
 
 ;;; Limitation of Warranty
 
-;; This program is free software: you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation, either version 3 of the License, or (at
-;; your option) any later version.
+;; This program is free software: you can redistribute it and/or
+;; modify it under the terms of the GNU General Public License as
+;; published by the Free Software Foundation, either version 3 of the
+;; License, or (at your option) any later version.
 ;;
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; This program is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ;; General Public License for more detail.
 ;;
@@ -392,9 +393,15 @@
   (d-add-to-dotemacs)
   (message                         "Finished configure script")
   (message                         "Note that online help is available in the files:")
-  (message                 (format "(1) %s/share/doc/jtw-manual/*.html and"              *prefix*))
-  (message                 (format "(2) %s/share/info/jtw-manual.info.gz"                *prefix*))
-  (message                 (format "(3) %s/info/jtw-manual.info.gz"                      *prefix*))
-  (message                         "\n")
+  (if (file-exists-p (format "%s/share/doc/jtw-manual/index.html" *prefix*))
+      (message             (format "(1) %s/share/doc/jtw-manual/*.html" *prefix*))
+    (message               (format "(1) Not found: %s/share/doc/jtw-manual/*.html" *prefix*)))
+  (if (file-exists-p (format "%s/share/info/jtw-manual.info.gz" *prefix*))
+      (message             (format "(2) %s/share/info/jtw-manual.info.gz" *prefix*))
+    (message               (format "(2) Not found: %s/share/info/jtw-manual.info.gz" *prefix*)))
+  (if (file-exists-p (format "%s/info/jtw-manual.info.gz" *prefix*))
+      (message             (format "(3) %s/info/jtw-manual.info.gz" *prefix*))
+    (message               (format "(3) Not found: %s/info/jtw-manual.info.gz" *prefix*)))
+  (message                     "\n")
   )
 
